function [X1,l1,v1,x]=esterno6(X,tol)
% La funzione svolge i calcoli relativi al ciclo iterativo esterno, richiamando pi volte,
% se necessario la funzione del ciclo interno. Riceve come input un valore iniziale di X,
% numero totale di moli di ammoniaca prodotte, ed una tolleranza. Restituisce nell' ordine:
% - il valore X1, numero di moli di ammoniaca prodotte al raggiungimento dell' equilibrio
%   chimico e di fase;
% - il valore l1, numero totale di moli in fase liquida;
% - il valore v1, numero totale di moli in fase vapore;
% - il vettore x, che contiene il numero di moli di ciascuna specie chimica, ripartite 
%   tra le due fasi presenti, sempre alle condizioni finali di equilibrio.
% In questo caso per la risoluzione del problema viene preso in esame il sistema lineare 
% costituito da 6 equazioni.

X0=X;
% Valore iniziale X del numero totale di moli di ammoniaca che si suppone siano presenti 
% in condizioni di equilibrio.
A06=matrix6(5,4-X0);
b06=vect6(X0);
[l1,v1,ammv,x]=interno6(X0,tol);
% Il ciclo interno viene eseguito una prima volta; si richiedono solo i primi 4 
% parametri in uscita, utili per il proseguimento del processo di calcolo.
nitrv=0.0449*sqrt(ammv*v1);
X1=2*(1-nitrv);
A16=matrix6(l1,v1);
b16=vect6(X1);
% Utilizzando l'espressione della costante di equilibrio di reazione viene calcolato un
% nuovo valore di X, indicato con X1. Si procede dunque alla valutazione dello scarto 
% relativo tra i due valori successivi. La quantit che si ottiene diventa l'elemento 
% fondamentale su cui basare il criterio di arresto.
count=1;
[ban(count),mag(count)]=perturbazione(A06,A16,b06,b16);
% Vengono eseguite le stime delle maggiorazioni con le perturbazioni su matrice dl sistema
% e vettore dei termini noti dovute all'esecuzione di un ciclo.
devx=norm(X1-X0)/norm(X0);
while devx>=tol  % Test di tolleranza.
   A06=A16;
   b06=b16;
   % L'aggiornamento della matrice e del vettore vengono svolti per poter fare uso
   % in seguito della funzione perturbazione.
   X0=X1;
   % Il nuovo valore di X diventa punto di partenza per questo passo successivo.
   [l1,v1,ammv,x]=interno6(X0,tol);
   % Richiamo del ciclo interno a cui viene passato come parametro il valore di X 
   % aggiornato.
   nitrv=0.0449*sqrt(ammv*v1);
   X1=2*(1-nitrv);
   % Aggiornamento di X.
   A16=matrix6(l1,v1);
   b16=vect6(X1);
   % Aggiornamento della matrice e del vettore dei termini noti.
   count=count+1;
   [ban(count),mag(count)]=perturbazione(A06,A16,b06,b16);  
   devx=norm(X1-X0)/norm(X0);
end
disp(ban');
disp(mag');
% Si visualizzano i risultati della funzione perturbazione che, applicata al ciclo
% esterno deve tener conto delle variazioni della matrice del sistema e del vettore dei
% termini noti.